@@ -9,13 +9,21 @@ use Printer::ESCPOS;
 use Data::Dumper;
 
 my $printer_usb = Printer::ESCPOS->new(
-    driverType     => 'USB',
-    vendorId       => 0x1504,
-    productId      => 0x0006,
+    driverType => 'USB',
+    vendorId   => 0x1cbe,
+    productId  => 0x0002,
+    endPoint   => 0x02
 );
 
-$printer_usb->printer->init();
+say Dumper $printer_usb->printer->printerStatus();
+say Dumper $printer_usb->printer->offlineStatus();
+say Dumper $printer_usb->printer->errorStatus();
+say Dumper $printer_usb->printer->paperSensorStatus();
 
+$printer_usb->printer->rot90(49);
+$printer_usb->printer->text("Rotated 90 degrees\n");
+$printer_usb->printer->rot90(0);
+$printer_usb->printer->text("Not rotated 90 degrees\n");
 
 $printer_usb->printer->barcode(
     barcode     => 'SHANTANU BHADORIA',
