@@ -13,7 +13,7 @@ package Printer::ESCPOS::Connections::USB;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 # Dependencies
 
@@ -70,6 +70,20 @@ sub _build__connection {
 }
 
 
+sub read {
+    my ( $self, $question, $bytes ) = @_;
+    my $data;
+    $bytes |= 1024;
+
+    $self->_connection->bulk_write( $self->endPoint, $question,
+        $self->timeout );
+    $self->_connection->bulk_read( $self->endPoint, $data, $bytes,
+        $self->timeout );
+
+    return $data;
+}
+
+
 sub print {
     my ( $self, $raw ) = @_;
     my @chunks;
@@ -101,7 +115,7 @@ Printer::ESCPOS::Connections::USB - USB Connection Interface for L<Printer::ESCP
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -168,6 +182,10 @@ Timeout for bulk write functions for the USB printer.
 
 =head1 METHODS
 
+=head2 read
+
+Read Data from the printer 
+
 =head2 print
 
 Sends buffer data to the printer.
