@@ -13,7 +13,7 @@ package Printer::ESCPOS::Profiles::Generic;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -253,6 +253,13 @@ sub leftMargin {
     $self->driver->write( _GS . 'L' . chr( $params{nL} ) . chr( $params{nH} ) );
 }
 
+
+sub rot90 {
+    my ( $self, $rot ) = @_;
+
+    $self->driver->write( _ESC . 'V' . chr($rot) );
+}
+
 # This is a redundant function in ESCPOS which updates the printer
 sub _updatePrintMode {
     my ($self) = @_;
@@ -480,7 +487,7 @@ Printer::ESCPOS::Profiles::Generic - Generic Profile for Printers for L<Printer:
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 METHODS
 
@@ -695,6 +702,15 @@ For example, to break the value 520 into two bytes, use the following two equati
 
     $device->printer->leftMargin(nL => $nl, nH => $nh);
 
+=head2 rot90
+
+Rotate printout by 90 degrees
+
+    $device->printer->rot90(1);
+    $device->printer->text("This is rotated 90 degrees\n");
+    $device->printer->rot90(0);
+    $device->printer->text("This is not rotated 90 degrees\n");
+
 =head2 barcode
 
 This method prints a barcode to the printer. This can be bundled with other text formatting commands at the appropriate point where you would like to print a barcode on your print out. takes argument ~barcode~ as the barcode value.
